<?php

namespace Assetdocs\Assetsrequest\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Form;
use Assetdocs\Assetsrequest\Http\Requests\AssetreqhdAdminWebRequest;
use Assetdocs\Assetsrequest\Interfaces\AssetreqhdRepositoryInterface;
use Assetdocs\Assetsrequest\Models\Assetreqhd;

/**
 * Admin web controller class.
 */
class AssetreqhdAdminController extends BaseController
{
    /**
     * The authentication guard that should be used.
     *
     * @var string
     */
    protected $guard = 'admin.web';

    /**
     * Initialize assetreqhd controller.
     *
     * @param type AssetreqhdRepositoryInterface $assetreqhd
     *
     * @return type
     */
    public function __construct(AssetreqhdRepositoryInterface $assetreqhd)
    {
        $this->middleware('web');
        $this->middleware('auth:admin.web');
        $this->setupTheme(config('theme.themes.admin.theme'), config('theme.themes.admin.layout'));

        $this->repository = $assetreqhd;
        parent::__construct();
    }

    /**
     * Display a list of assetreqhd.
     *
     * @return Response
     */
    public function index(AssetreqhdAdminWebRequest $request)
    {
        $pageLimit = $request->input('pageLimit');
        if ($request->wantsJson()) {
            $assetreqhds  = $this->repository
            ->pushCriteria(new \Assetdocs\Assetsrequest\Repositories\Criteria\AssetreqhdAdminCriteria())
                ->setPresenter('\\Assetdocs\\Assetsrequest\\Repositories\\Presenter\\AssetreqhdListPresenter')
                ->scopeQuery(function ($query) {
                    return $query->orderBy('id', 'DESC');
                })->paginate($pageLimit);

            $assetreqhds['recordsTotal']    = $assetreqhds['meta']['pagination']['total'];
            $assetreqhds['recordsFiltered'] = $assetreqhds['meta']['pagination']['total'];
            $assetreqhds['request']         = $request->all();
            return response()->json($assetreqhds, 200);

        }

        $this   ->theme->prependTitle(trans('assetsrequest::assetreqhd.names').' :: ');
        return $this->theme->of('assetsrequest::admin.assetreqhd.index')->render();
    }

    /**
     * Display assetreqhd.
     *
     * @param Request $request
     * @param Model   $assetreqhd
     *
     * @return Response
     */
    public function show(AssetreqhdAdminWebRequest $request, Assetreqhd $assetreqhd)
    {
        if (!$assetreqhd->exists) {
            return response()->view('assetsrequest::admin.assetreqhd.new', compact('assetreqhd'));
        }

        Form::populate($assetreqhd);
        return response()->view('assetsrequest::admin.assetreqhd.show', compact('assetreqhd'));
    }

    /**
     * Show the form for creating a new assetreqhd.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(AssetreqhdAdminWebRequest $request)
    {

        $assetreqhd = $this->repository->newInstance([]);

        Form::populate($assetreqhd);

        return response()->view('assetsrequest::admin.assetreqhd.create', compact('assetreqhd'));

    }

    /**
     * Create new assetreqhd.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(AssetreqhdAdminWebRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.web');
            $assetreqhd          = $this->repository->create($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('assetsrequest::assetreqhd.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/assetsrequest/assetreqhd/'.$assetreqhd->getRouteKey())
            ], 201);


        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
            ], 400);
        }
    }

    /**
     * Show assetreqhd for editing.
     *
     * @param Request $request
     * @param Model   $assetreqhd
     *
     * @return Response
     */
    public function edit(AssetreqhdAdminWebRequest $request, Assetreqhd $assetreqhd)
    {
        Form::populate($assetreqhd);
        return  response()->view('assetsrequest::admin.assetreqhd.edit', compact('assetreqhd'));
    }

    /**
     * Update the assetreqhd.
     *
     * @param Request $request
     * @param Model   $assetreqhd
     *
     * @return Response
     */
    public function update(AssetreqhdAdminWebRequest $request, Assetreqhd $assetreqhd)
    {
        try {

            $attributes = $request->all();

            $assetreqhd->update($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('assetsrequest::assetreqhd.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/assetsrequest/assetreqhd/'.$assetreqhd->getRouteKey())
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/assetsrequest/assetreqhd/'.$assetreqhd->getRouteKey()),
            ], 400);

        }
    }

    /**
     * Remove the assetreqhd.
     *
     * @param Model   $assetreqhd
     *
     * @return Response
     */
    public function destroy(AssetreqhdAdminWebRequest $request, Assetreqhd $assetreqhd)
    {

        try {

            $t = $assetreqhd->delete();

            return response()->json([
                'message'  => trans('messages.success.deleted', ['Module' => trans('assetsrequest::assetreqhd.name')]),
                'code'     => 202,
                'redirect' => trans_url('/admin/assetsrequest/assetreqhd/0'),
            ], 202);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/assetsrequest/assetreqhd/'.$assetreqhd->getRouteKey()),
            ], 400);
        }
    }
}
